unit ProjInfo;
interface
uses
  ShareMem, WinTypes, WinProcs, ExptIntf, DllIntf, SysUtils, Messages, Classes,
  Graphics, Controls, Forms, Dialogs, ExtCtrls, StdCtrls, Buttons, Grids;

Type
  TInformationForm = class(TForm)
    Panel: TPanel;
    Label1: TLabel;
    Label2: TLabel;
    StringGrid1: TStringGrid;
    ExpandBtn: TBitBtn;
    ReduceBtn: TBitBtn;
    OK: TBitBtn;
    ViCiouSBtn: TBitBtn;
    procedure UpdateProj(Sender: TObject);
    procedure ExpandBtnClick(Sender: TObject);
    procedure ReduceBtnClick(Sender: TObject);
    procedure OKClick(Sender: TObject);
    procedure ViCiouS(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    Mw,Mh : Integer;
    procedure WMGetMinMaxInfo(var Message: TWMGetMinmaxInfo);
              message WM_GETMINMAXINFO;
  end {TInformationForm};

{$IFDEF WIN32}
Var
{$ELSE}
Const
{$ENDIF}
  InformationForm: TInformationForm = nil;

Type
  TProjectInfoExpert = class(TIExpert)
  public
    { Expert Style }
    function GetStyle: TExpertStyle; override;
    { Expert Strings }
    function GetIDString: String; override;
    function GetName: String; override;
  {$IFDEF WIN32}
    function GetAuthor: String; override;
  {$ENDIF}
    function GetMenuText: String; override;
    function GetState: TExpertState; override;
    { Launch the Expert }
    procedure Execute; override;
  end {ProjectInfoExpert};

{$IFDEF WIN32}
Var
{$ELSE}
Const
{$ENDIF}
  ProjectInfoExpert: TProjectInfoExpert = nil;

  procedure DoneExpert;

implementation
{$R *.DFM}

  function TProjectInfoExpert.GetStyle: TExpertStyle;
  begin
    Result := esStandard
  end {GetStyle};

  function TProjectInfoExpert.GetIDString: String;
  begin
    Result := 'DrBob.TProjectInfoExpert'
  end {GetIDString};

  function TProjectInfoExpert.GetName: String;
  begin
    Result := 'Dr.Bob''s Project Info Expert'
  end {GetName};

{$IFDEF WIN32}
  function TProjectInfoExpert.GetAuthor: String;
  begin
    Result := 'Dr.Bob'
  end {GetAuthor};
{$ENDIF}

  function TProjectInfoExpert.GetMenuText: String;
  begin
    Result := 'No Project Information Available';
    try
      if Assigned(ToolServices) and
        (ToolServices.GetUnitCount > 0) and
        (ToolServices.GetFormCount > 0) and
        (Length(ToolServices.GetProjectName) > 0) then
        Result := '&Project Info about ' +
                    ExtractFileName(ToolServices.GetProjectName) + '...'
    except
      HandleException
    end
  end {GetMenuText};

  function TProjectInfoExpert.GetState: TExpertState;
  begin
    Result := [];
    try
      if Assigned(ToolServices) and
        (ToolServices.GetUnitCount > 0) and
        (ToolServices.GetFormCount > 0) and
        (Length(ToolServices.GetProjectName) > 0) then
        Result := [esEnabled]
    except
      HandleException
    end
  end {GetState};

  procedure TProjectInfoExpert.Execute;
  begin
    try
      if not Assigned(InformationForm) then
        InformationForm := TInformationForm.Create(Application);
      InformationForm.UpdateProj(nil);
      InformationForm.Show
    except
      HandleException
    end
  end {Execute};

  procedure DoneExpert;
  begin
    try
      ProjectInfoExpert := nil; { 2.5 }
      if Assigned(InformationForm) then InformationForm.Free;
      InformationForm := nil
    except
      HandleException
    end
  end {DoneExpert};


procedure TInformationForm.FormCreate(Sender: TObject);
var DRBOB: THandle;
begin
  { 2 pixels for 3d borders and 20 for the space at the component edge }
  Mw := Ok.Left + Ok.Width + Panel.BorderWidth + 2 + 20;
  Mh := (Height - ClientHeight) +
         ReduceBtn.Top +
         ReduceBtn.Height +
         Panel.BorderWidth + 2 + 20 {1.03} -10 {1.03};
  Left := GetSystemMetrics(SM_CXFULLSCREEN) - Mw - 1;
  Top := GetSystemMetrics(SM_CYFULLSCREEN) - Mh + 17;
  try
    DRBOB := GetModuleHandle('VICIOUS.DLL');
    ViCiouSBtn.Enabled := DRBOB > 0;
  except
    HandleException
  end
end {FormCreate};

procedure TInformationForm.WMGetMinMaxInfo(var Message: TWMGetMinmaxInfo);
var MinMax: PMinMaxInfo;
begin
  inherited;
  MinMax := Message.MinMaxInfo;
  MinMax^.ptMinTrackSize.X := Mw;
  MinMax^.ptMaxTrackSize.X := Mw;
  MinMax^.ptMinTrackSize.Y := Mh;
end {GetWMMinMaxInfo};

procedure TInformationForm.FormResize(Sender: TObject);
begin
  if Assigned(StringGrid1) then
    StringGrid1.Height := ClientHeight - StringGrid1.Top - 20;
end {FormResize};

procedure TInformationForm.UpdateProj(Sender: TObject);
var FormCount,UnitCount,i,j: Integer;
    FormName,UnitName: ShortString;
begin
  try
    StringGrid1.Cells[0,0] := 'units: 0';
    StringGrid1.Cells[1,0] := 'forms: 0';
    if Assigned(ToolServices) then
    begin
      FormCount := ToolServices.GetFormCount;
      UnitCount := ToolServices.GetUnitCount;
      if FormCount * UnitCount > 0 then {!!}
        FormName := ToolServices.GetProjectName
    end
    else
    begin
      FormCount := 0;
      UnitCount := 0;
      FormName := 'no ToolServices available'
    end;
    ExpandBtn.Enabled := UnitCount > 0;
    ReduceBtn.Enabled := UnitCount > 0;
    StringGrid1.Cells[1,0] := Format('forms: %d',[FormCount]);
    Label1.Caption := ExtractFileName(FormName);
    Label2.Caption := FormName;
    for i:=1 to StringGrid1.RowCount do
    begin
      StringGrid1.Cells[0,i] := '';
      StringGrid1.Cells[1,i] := ''
    end;
    if UnitCount > 0 then
  {$IFDEF WIN32}
      StringGrid1.Cells[0,0] := Format('units: %d',[UnitCount]);
    for i:=0 to Pred(UnitCount) do
  {$ELSE}
      StringGrid1.Cells[0,0] := Format('units: %d',[UnitCount+1]);
    for i:=0 to UnitCount do
  {$ENDIF}
    begin
      UnitName := ToolServices.GetUnitName(i);
    { if (CPPBuilder in IDE) then ShowMessage(UnitName); }
      UnitName := UpperCase(ExtractFileName(UnitName));
    { if (CPPBuilder in IDE) then ShowMessage(UnitName); }
      StringGrid1.Cells[0,i+1] := UnitName;
      if ShareMem.Delphi and (Pos('.PAS',UnitName) > 0) then
      begin
        j := 0;
        repeat
          FormName := ToolServices.GetFormName(j);
          FormName := UpperCase(ExtractFileName(FormName));
          if FormName = ChangeFileExt(UnitName,'.DFM') then
          begin
            StringGrid1.Cells[1,i+1] := FormName;
            j := FormCount
          end
          else Inc(j)
        until j >= FormCount
      end
      else
      begin
        if not ShareMem.Delphi then
        begin
          if Pos('.CPP',UnitName) > 0 then
          begin
            j := 0;
            repeat
              FormName := ToolServices.GetFormName(j);
              FormName := UpperCase(ExtractFileName(FormName));
              if FormName = ChangeFileExt(UnitName,'.DFM') then
              begin
                StringGrid1.Cells[1,i+1] := FormName;
                j := FormCount
              end
              else Inc(j)
            until j >= FormCount
          end
          else
            StringGrid1.Cells[1,i+1] := '-'
        end
        else
          StringGrid1.Cells[1,i+1] := '-'
      end
    end
  except
    HandleException
  end
end {FormActivate};

procedure TInformationForm.ExpandBtnClick(Sender: TObject);
var i: Integer;
begin
  try
    if Assigned(ToolServices) then with ToolServices do
    begin
      SaveProject;
    {$IFDEF WIN32}
      for i:=2 to Pred(GetUnitCount) do
    {$ELSE}
      for i:=2 to GetUnitCount do
    {$ENDIF}
        OpenFile(GetUnitName(i))
    end
  except
    HandleException
  end
end {ExpandBtnClick};

procedure TInformationForm.ReduceBtnClick(Sender: TObject);
var i: Integer;
begin
  try
    if Assigned(ToolServices) then with ToolServices do
    begin
      SaveProject;
    {$IFDEF WIN32}
      for i:=1 to Pred(GetUnitCount) do
    {$ELSE}
      for i:=1 to GetUnitCount do
    {$ENDIF}
        CloseFile(GetUnitName(i))
    end
  except
    HandleException
  end
end {ReduceBtnClick};

procedure TInformationForm.OKClick(Sender: TObject);
begin
  Hide
end {OKClick};

procedure TInformationForm.ViCiouS(Sender: TObject);
var DRBOB: THandle;
    CallViCiouS: procedure;
    CheckOutViCiouS: procedure(Nr: Integer);
begin
  try
    DRBOB := GetModuleHandle('VICIOUS.DLL');
    ViCiouSBtn.Enabled := DRBOB > 0;
    if DRBOB > 0 then
    begin
      if (Sender IS TBitBtn) then
      begin
        @CheckOutViCiouS := GetProcAddress(DRBOB,'CheckOutViCiouS');
        if (@CheckOutViCiouS <> nil) then CheckOutViCiouS(StringGrid1.Row)
        else
        begin
          @CallViCiouS := GetProcAddress(DRBOB,'CallViCiouS');
          if (@CallViCiouS <> nil) then CallViCiouS
                                   else MessageBeep($FFFF)
        end
      end
    end
  except
    HandleException
  end
end {ViCiouS};

end.
