unit SysInfo;
interface
uses ShareMem, WinTypes, ExptIntf, DllIntf,
     SysUtils, Classes, Forms, Controls, StdCtrls, TabNotBk
     {$IFDEF WIN32}
     , ComCtrls
     {$ENDIF}
     ;

Type
  TSysInfoForm = class(TForm)
    TabbedNotebook1: TTabbedNotebook;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure TabbedNotebook1Change(Sender: TObject; NewTab: Integer;
      var AllowChange: Boolean);
  end {TSysInfoForm};

{$IFDEF WIN32}
Var
{$ELSE}
Const
{$ENDIF}
  SysInfoForm: TSysInfoForm = nil;

Type
  TSysInfoExpert = class(TIExpert)
  public
    { Expert Style }
    function GetStyle: TExpertStyle; override;
    { Expert Strings }
    function GetIDString: string; override;
    function GetName: string; override;
  {$IFDEF WIN32}
    function GetAuthor: String; override;
  {$ENDIF}
    function GetMenuText: string; override;
    function GetState: TExpertState; override;
    { Launch the Expert }
    procedure Execute; override;
  end {TSysInfoExpert};

  procedure DoneExpert;

implementation
{$R *.DFM}

  function TSysInfoExpert.GetStyle: TExpertStyle;
  begin
    Result := esStandard
  end {GetStyle};

  function TSysInfoExpert.GetIDString: String;
  begin
    try
      Result := 'DrBob.TSysInfoExpert'
    except
      HandleException
    end
  end {GetIDString};

  function TSysInfoExpert.GetName: String;
  begin
    try
      Result := 'SysInfo'
    except
      HandleException
    end
  end {GetName};

{$IFDEF WIN32}
  function TSysInfoExpert.GetAuthor: String;
  begin
    try
      Result := 'Dr.Bob'
    except
      HandleException
    end
  end {GetAuthor};
{$ENDIF}

  function TSysInfoExpert.GetMenuText: String;
  { NOTE: You can apply the following 'trick' to any GetMenuText
    of the other Experts/Wizards of this collection as well... }
  begin
    try
      if (ShareMem.Delphi) and (ShareMem.Version = 2) then
        Result := '&SysUtils Info Expert...'
      else
        Result := '&SysUtils Info Wizard...'
    except
      HandleException
    end
  end {GetMenuText};

  function TSysInfoExpert.GetState: TExpertState;
  begin
    try
      Result := [esEnabled]
    except
      HandleException
    end
  end {GetState};

  procedure TSysInfoExpert.Execute;
  begin
    try
      if not Assigned(SysInfoForm) then
        SysInfoForm := TSysInfoForm.Create(Application);
      SysInfoForm.Show
    except
      HandleException
    end
  end {Execute};

  procedure DoneExpert;
  begin
    try
      if Assigned(SysInfoForm) then SysInfoForm.Free;
      SysInfoForm := nil
    except
      HandleException
    end
  end {DoneExpert};



procedure TSysInfoForm.FormCreate(Sender: TObject);
begin
  try
    Label4.Font.Size := Label4.Font.Size * 2 - 6;
    TabbedNotebook1.PageIndex := 3
  except
    HandleException
  end
end {FormCreate};

procedure TSysInfoForm.TabbedNotebook1Change(Sender: TObject;
  NewTab: Integer; var AllowChange: Boolean);
var i: Integer;
begin
  try case NewTab of
    0: Label1.Caption := #13+
                         'CurrencyString = ' + CurrencyString + #13+
                         'CurrencyFormat = ' + IntToStr(CurrencyFormat) + #13+
                         ' NegCurrFormat = ' + IntToStr(NegCurrFormat) + #13#13+
                         'ThousandSeparator = ' + ThousandSeparator + #13+
                         ' DecimalSeparator = ' + DecimalSeparator + #13+
                         ' CurrencyDecimals = ' + IntToStr(CurrencyDecimals);
    1: begin
         Label2.Caption := #13+
           Format('DateSeparator = %s'#13'ShortDateFormat = %s'#13'LongDateFormat = %s'#13#13'ShortMonthNames = (',
                  [DateSeparator,ShortDateFormat,LongDateFormat]);
         for i:=1 to 12 do
         begin
           Label2.Caption := Label2.Caption + ShortMonthNames[i];
           if i < 12 then Label2.Caption := Label2.Caption + ', '
         end;
         Label2.Caption := Label2.Caption + ')' + #13 + 'LongMonthNames = (...)' + #13 +
           'ShortDayNames = (';
         for i:=1 to 7 do
         begin
           Label2.Caption := Label2.Caption + ShortDayNames[i];
           if i < 7 then Label2.Caption := Label2.Caption + ','
         end;
         Label2.Caption := Label2.Caption + ') ' + #13 +
           'LongDayNames = (...)'
       end;
    2: Label3.Caption := #13+
                         'TimeSeparator = ' + TimeSeparator + #13 +
                         'TimeAMString = ' + TimeAMString + #13 +
                         'TimePMString = ' + TimePMString + #13 +
                         'ShortTimeFormat = ' + ShortTimeFormat + #13 +
                         'LongTimeFormat = ' + LongTimeFormat + #13 + #13 +
                         'DateSeparator = ' + DateSeparator + #13 +
                         'ShortDateFormat = ' + ShortDateFormat + #13 +
                         'LongDateFormat = ' + LongDateFormat;
    3: begin
         Label4.Alignment := taCenter;
         Label4.Caption := #13'DrBob.DLL 2.50'#13#13;
       {$IFDEF WIN32}
         if ShareMem.Delphi then
         begin
           Label4.Caption := Label4.Caption + 'for Borland Delphi';
         { if ShareMem.Version = 2 then
             Label4.Caption := Label4.Caption + ' 2.x'#13
           else
             Label4.Caption := Label4.Caption + ' 3'#13 }
         end
         else
           Label4.Caption := Label4.Caption + 'for Borland C++Builder'#13;
       {$ELSE}
         Label4.Caption := Label4.Caption + 'for Borland Delphi 1.x'#13;
       {$ENDIF}
         Label4.Caption := Label4.Caption + #13'running on'#13;
       {$IFDEF WIN32}
         Label4.Caption := Label4.Caption + #13'Microsoft Win32'
       {$ELSE}
         Label4.Caption := Label4.Caption + #13'Microsoft Windows 3.1'
       {$ENDIF}
       end;
    4: begin
         Label5.Caption := '';
         for i:=3 to 26 do
           if DiskSize(i) > -1 then
             label5.Caption := label5.Caption +
               Format('  Disk %s:%10d Kbytes,%10d Kb free'#13,
                 [Chr(Ord('A')+i-1),DiskSize(i) div 1024,DiskFree(i) div 1024])
       end;
  end
  except
    HandleException
  end
end;

end.
